@REM  THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
@REM  5724-I63, 5724-H88, 5655-N01, 5733-W61 (C) COPYRIGHT International Business Machines Corp., 1997,2016
@REM  All Rights Reserved * Licensed Materials - Property of IBM
@REM  US Government Users Restricted Rights - Use, duplication or disclosure
@REM  restricted by GSA ADP Schedule Contract with IBM Corp.
@REM 
@REM  DESCRIPTION: This script is called from setupCmdLine.bat and setupClient.bat
@REM  ###########################################################################
@echo off

@REM  ###########################################################################
@REM  pushd "%~dp0" - temp set the drive/path for this script.  Then relative 
@REM  paths can be used.  popd "%~dp0" will restore to the previous setting
@REM  ###########################################################################
pushd "%~dp0"

@REM  ###########################################################################
@REM  Read the cmdDefaultSDK.properties file to get the current value of 
@REM  COMMAND_DEFAULT_SDK ( ..\..\properties\sdk\cmdDefaultSDK.properties )
@REM  ###########################################################################
SETLOCAL ENABLEDELAYEDEXPANSION 
FOR /F "tokens=1-2 delims== " %%a IN ( ..\..\properties\sdk\cmdDefaultSDK.properties ) DO (
  SET command_default_sdk=%%a
  SET value=%%b
  IF "!command_default_sdk!" EQU "COMMAND_DEFAULT_SDK" (
     break
  )   
)
set COMMAND_DEFAULT_SDK=%value%

@REM  ###########################################################################
@REM  If the COMMAND_SDK is uninitialized, it's the first time here.
@REM  In this case, we want to use the highest available sdk.
@REM  Parse through the java directories to find one.
@REM  ###########################################################################

if "%value%"=="uninitialized" (
  set value="0.0"

  @REM Loop variables
  set JAVADIRSTRING=""
  set \a JAVADIRNUMERIC=0

  @REM Loop through java directories, looking for the highest installed version
  @REM WebSphere must install at least one java    
  for /D %%c in ( "%~dp0..\..\java\*" ) do (
     if exist "%%c\jre\bin\java.exe" (
        @REM Remove the path leaving the last dir name, it should be something like 8.0 now
        for /D %%f in ("%%c") do set JAVADIRSTRING=%%~nxf
        
        @REM Remove any decimal points and save it as a number, like 80
        set /a JAVADIRNUMERIC=!JAVADIRSTRING:.=!
       
        @REM If this java version is higher, use it
        if !JAVADIRNUMERIC! gtr !value! (
            set value=!JAVADIRSTRING!
        )
     )
  )   

  @REM Add on the bit-ness, based on the installed properties file
  if exist "%WAS_HOME%\properties\sdk\!value!_64.properties" ( 
      set value=!value!_64
  ) else (
       if exist "%WAS_HOME%\properties\sdk\!value!_32.properties" (
           set value=!value!_32
       ) else ( 
           set value=!value!_31
       )
  )
  
  @REM Pipe the default SDK version into the command and profile default files.
  echo COMMAND_DEFAULT_SDK=!value!>"%WAS_HOME%\properties\sdk\cmdDefaultSDK.properties"
  echo com.ibm.websphere.sdkname.newProfileDefaultSDK=!value!>"%WAS_HOME%\properties\sdk\newProfileDefaultSDK.properties"
)
ENDLOCAL & set COMMAND_DEFAULT_SDK=%value%  

set COMMAND_SDK=%COMMAND_DEFAULT_SDK%

@REM  ###########################################################################
@REM  Call the script that sets the HIGHEST_AVAILABLE_SDK variable
@REM  if the calling script has set USE_HIGHEST_AVAILABLE_SDK to a 
@REM  value of "true"
@REM  ###########################################################################
if  "%USE_HIGHEST_AVAILABLE_SDK%"=="true" (
  if exist "%~dp0_highest_available_sdk.bat" (
     CALL "%~dp0_highest_available_sdk.bat" %*
  ) 
)
@REM  ###########################################################################
@REM  Set the COMMAND_SDK from the output of calling the 
@REM  _highest_available_sdk.bat file above if the calling script has set
@REM  USE_HIGHEST_AVAILABLE_SDK to a value of "true"
@REM  This could not be done in the same if statement ... requires two   
@REM  ###########################################################################
if  "%USE_HIGHEST_AVAILABLE_SDK%"=="true" (   
   if DEFINED HIGHEST_AVAILABLE_SDK (
      SET COMMAND_SDK=%HIGHEST_AVAILABLE_SDK%
   ) 
)
@REM  ###########################################################################                                                                                 
@REM  COMMAND_OVERRIDE_SDK variable exists, its value will be used!
@REM  If variable value is not a valid sdkName this script will fail!
@REM  Valid sdkNames will have the format 1.6_32 (sdk version_bitness)
@REM  ###########################################################################
if  "%USE_COMMAND_OVERRIDE_SDK%"=="true" ( 
  if DEFINED COMMAND_OVERRIDE_SDK (
     SET COMMAND_SDK=%COMMAND_OVERRIDE_SDK%
  )    
)
@REM  ###########################################################################                                                                                 
@REM  Trim trailing blanks 
@REM  ###########################################################################
SET COMMAND_SDK=%COMMAND_SDK: =%

@REM  ###########################################################################
@REM  Call the _setup<sdkname> script to set the current JAVA_HOME path
@REM  ###########################################################################
CALL "%~dp0_setupsdk%COMMAND_SDK%.bat"  %*

popd "%~dp0"

